select.fanc: Select a Model from a "fanc" Object

selectR Documentation

Select a Model from a "fanc" Object

Description

Selects the value of rho that minimizes a model-selection criterion, optionally at a specified value of gamma.

Usage

select(x, criterion=c("BIC","AIC","CAIC","EBIC"), 
	gamma,  scores=FALSE, df.method="active")

Arguments

x

Fitted "fanc" model object.

criterion

The criterion by which to select the tuning parameter rho. One of "AIC", "BIC", "CAIC", or "EBIC". Default is "BIC".

gamma

The value of gamma.

scores

Logical flag for outputting factor scores. The original data matrix must have been supplied to fanc. The default is FALSE.

df.method

Two types of degrees of freedom are supported. If "active", the degrees of freedom are the number of nonzero parameters. If "reparametrization", the degrees of freedom of the MC+ are reparametrized based on the degrees of freedom of the lasso.

Value

loadings

factor loadings

uniquenesses

unique variances

Phi

Factor-correlation matrix, when factor correlations were estimated.

scores

Factor scores, when scores=TRUE.

df

Degrees of freedom under the selected df.method.

AIC, BIC, CAIC, EBIC

The value of the selected criterion.

goodness.of.fit

Values of GFI, AGFI, CFI, RMSEA and SRMR, when available.

rho

The selected value of rho.

gamma

The selected value of gamma.

Author(s)

Kei Hirose
mail@keihirose.com

References

Hirose, K. and Yamamoto, M. (2015). Sparse estimation via nonconcave penalized likelihood in a factor analysis model,
Statistics and Computing, 25, 633–648.

See Also

fanc and plot.fanc objects.


fanc documentation built on July 26, 2026, 9:06 a.m.

Related to select.fanc in fanc...